#[repr(C)]pub struct IAccountMeta {
pub pubkey: Pubkey,
pub writable: u8,
}Fields
pubkey: Pubkeywritable: u8Trait Implementations
sourceimpl BorshDeserialize for IAccountMetawhere
Pubkey: BorshDeserialize,
u8: BorshDeserialize,
impl BorshDeserialize for IAccountMetawhere
Pubkey: BorshDeserialize,
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl BorshSerialize for IAccountMetawhere
Pubkey: BorshSerialize,
u8: BorshSerialize,
impl BorshSerialize for IAccountMetawhere
Pubkey: BorshSerialize,
u8: BorshSerialize,
sourceimpl Clone for IAccountMeta
impl Clone for IAccountMeta
sourcefn clone(&self) -> IAccountMeta
fn clone(&self) -> IAccountMeta
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for IAccountMeta
impl Debug for IAccountMeta
sourceimpl PartialEq for IAccountMeta
impl PartialEq for IAccountMeta
sourcefn eq(&self, other: &IAccountMeta) -> bool
fn eq(&self, other: &IAccountMeta) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Copy for IAccountMeta
impl Eq for IAccountMeta
impl StructuralEq for IAccountMeta
impl StructuralPartialEq for IAccountMeta